#include "aesopd.h"

Connection *conn = NULL;		/* Pointer to array of Connection structures 	*/
int conn_size = 0;			/* Number of Connection structures in array  	*/
fd_set rdset, wrset;			/* Global read and write sets		     	*/
int maxfd;				/* Global maxfd variable used for select()	*/
int lfd;				/* Copy of the main server listen FD		*/
int max_simul_con = MAX_SIMUL_CONNECT;	/* Maximum simultaneous connections		*/
int sndbufsz = 0;			/* Size of TCP Sendbuffer			*/
int sp_base  = -1;			/* Source port specification base		*/
int timeout  = -1;			/* Timeout					*/
char *AuthData = NULL;
R_RSA_PRIVATE_KEY ServerPrivateKey;	/* Global Private RSA key of the server		*/

#ifdef IPV6
int ipv6support = 1;
#else
int ipv6support = 0;
#endif

char *keywords[] = {
   "ChrootDir",
   "User",
   "Group",
   "MaxSimulConn",
   "BufferSize",
   "PrivateKeyFile",
   "TimeOut",
   "SourcePortBase",
   "SeedFile",
   "AuthString",
   "LogFile",
   NULL
};
